"""
    HW Mux Reservation System

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1.6
    Generated by: https://openapi-generator.tech
"""


import unittest

import hwmux_client
from hwmux_client.api.devices_api import DevicesApi  # noqa: E501


class TestDevicesApi(unittest.TestCase):
    """DevicesApi unit test stubs"""

    def setUp(self):
        self.api = DevicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_devices_create(self):
        """Test case for devices_create

        """
        pass

    def test_devices_destroy(self):
        """Test case for devices_destroy

        """
        pass

    def test_devices_list(self):
        """Test case for devices_list

        """
        pass

    def test_devices_list_my_list(self):
        """Test case for devices_list_my_list

        """
        pass

    def test_devices_location_retrieve(self):
        """Test case for devices_location_retrieve

        """
        pass

    def test_devices_partial_update(self):
        """Test case for devices_partial_update

        """
        pass

    def test_devices_release_update(self):
        """Test case for devices_release_update

        """
        pass

    def test_devices_reserve_update(self):
        """Test case for devices_reserve_update

        """
        pass

    def test_devices_retrieve(self):
        """Test case for devices_retrieve

        """
        pass

    def test_devices_search_list(self):
        """Test case for devices_search_list

        """
        pass

    def test_devices_set_offline_create(self):
        """Test case for devices_set_offline_create

        """
        pass

    def test_devices_update(self):
        """Test case for devices_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
