"""
    HW Mux Reservation System

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1.6
    Generated by: https://openapi-generator.tech
"""


import unittest

import hwmux_client
from hwmux_client.api.reservations_api import ReservationsApi  # noqa: E501


class TestReservationsApi(unittest.TestCase):
    """ReservationsApi unit test stubs"""

    def setUp(self):
        self.api = ReservationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_reservations_actionable_list(self):
        """Test case for reservations_actionable_list

        """
        pass

    def test_reservations_active_list(self):
        """Test case for reservations_active_list

        """
        pass

    def test_reservations_cancel_update(self):
        """Test case for reservations_cancel_update

        """
        pass

    def test_reservations_create(self):
        """Test case for reservations_create

        """
        pass

    def test_reservations_list(self):
        """Test case for reservations_list

        """
        pass

    def test_reservations_metadata_partial_update(self):
        """Test case for reservations_metadata_partial_update

        """
        pass

    def test_reservations_metadata_update(self):
        """Test case for reservations_metadata_update

        """
        pass

    def test_reservations_release_update(self):
        """Test case for reservations_release_update

        """
        pass

    def test_reservations_retrieve(self):
        """Test case for reservations_retrieve

        """
        pass

    def test_reservations_update(self):
        """Test case for reservations_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
