"""
    HW Mux Reservation System

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1.6
    Generated by: https://openapi-generator.tech
"""


import unittest

import hwmux_client
from hwmux_client.api.sites_api import SitesApi  # noqa: E501


class TestSitesApi(unittest.TestCase):
    """SitesApi unit test stubs"""

    def setUp(self):
        self.api = SitesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_sites_create(self):
        """Test case for sites_create

        """
        pass

    def test_sites_destroy(self):
        """Test case for sites_destroy

        """
        pass

    def test_sites_list(self):
        """Test case for sites_list

        """
        pass

    def test_sites_partial_update(self):
        """Test case for sites_partial_update

        """
        pass

    def test_sites_retrieve(self):
        """Test case for sites_retrieve

        """
        pass

    def test_sites_rooms_create(self):
        """Test case for sites_rooms_create

        """
        pass

    def test_sites_rooms_destroy(self):
        """Test case for sites_rooms_destroy

        """
        pass

    def test_sites_rooms_list(self):
        """Test case for sites_rooms_list

        """
        pass

    def test_sites_rooms_partial_update(self):
        """Test case for sites_rooms_partial_update

        """
        pass

    def test_sites_rooms_retrieve(self):
        """Test case for sites_rooms_retrieve

        """
        pass

    def test_sites_rooms_update(self):
        """Test case for sites_rooms_update

        """
        pass

    def test_sites_update(self):
        """Test case for sites_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
