"""
    HW Mux Reservation System

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1.6
    Generated by: https://openapi-generator.tech
"""


import unittest

import hwmux_client
from hwmux_client.api.part_families_api import PartFamiliesApi  # noqa: E501


class TestPartFamiliesApi(unittest.TestCase):
    """PartFamiliesApi unit test stubs"""

    def setUp(self):
        self.api = PartFamiliesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_part_families_create(self):
        """Test case for part_families_create

        """
        pass

    def test_part_families_destroy(self):
        """Test case for part_families_destroy

        """
        pass

    def test_part_families_list(self):
        """Test case for part_families_list

        """
        pass

    def test_part_families_partial_update(self):
        """Test case for part_families_partial_update

        """
        pass

    def test_part_families_parts_create(self):
        """Test case for part_families_parts_create

        """
        pass

    def test_part_families_parts_destroy(self):
        """Test case for part_families_parts_destroy

        """
        pass

    def test_part_families_parts_list(self):
        """Test case for part_families_parts_list

        """
        pass

    def test_part_families_parts_partial_update(self):
        """Test case for part_families_parts_partial_update

        """
        pass

    def test_part_families_parts_retrieve(self):
        """Test case for part_families_parts_retrieve

        """
        pass

    def test_part_families_parts_update(self):
        """Test case for part_families_parts_update

        """
        pass

    def test_part_families_retrieve(self):
        """Test case for part_families_retrieve

        """
        pass

    def test_part_families_update(self):
        """Test case for part_families_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
